@@ -371,9 +371,9 @@ def command_check(lookup, packages, options):
     uninstalled, errors = installer.get_uninstalled(packages, verbose=verbose)
 
     # pretty print the result
-    if [r for r in uninstalled.values() if r]:
+    if [v for k, v in uninstalled if v]:
         print("System dependencies have not been satisified:")
-        for installer_key, resolved in uninstalled.items():
+        for installer_key, resolved in uninstalled:
             if resolved:
                 for r in resolved:
                     print("%s\t%s"%(installer_key, r))
@@ -412,12 +412,16 @@ def command_install(lookup, packages, options):
     if options.reinstall:
         if options.verbose:
             print("reinstall is true, resolving all dependencies")
-        uninstalled, errors = lookup.resolve_all(packages, installer_context, implicit=options.recursive)
+        try:
+            uninstalled, errors = lookup.resolve_all(packages, installer_context, implicit=options.recursive)
+        except InvalidData as e:
+            print("ERROR: unable to process all dependencies:\n\t%s"%(e), file=sys.stderr)
+            return 1
     else:
         uninstalled, errors = installer.get_uninstalled(packages, implicit=options.recursive, verbose=options.verbose)
         
     if options.verbose:
-        print("uninstalled dependencies are: [%s]"%(', '.join(uninstalled.keys())))
+        print("uninstalled dependencies are: [%s]"%(', '.join([', '.join(pkg) for pkg in [v for k,v in uninstalled]])))
         
     if errors:
         print("ERROR: the following packages/stacks could not have their rosdep keys resolved\nto system dependencies:", file=sys.stderr)
